
JSON, XML schema
-------

**Description:**

When adding schema's to your JSON or XML files you have better controll over what 
type of userinput can be supplied in your application. This dramatically decreases an
attackers attack vector when implemented the right way. Nonetheless you should always 
apply your own input validation and rejection as extra layer of defence. This approach 
is also desirable since you also want to do countering and logging on the users 
requests and input.	 
 
**Solution:**

Verify that XML or JSON schema are in place and verified before accepting input.

Recommended knowledge base items:

- Input rejection
- Input validation
- Audit logs


